Package: neo4r
Title: A 'Neo4J' Driver
Version: 0.1.4
Authors@R: 
    c(person(given = "Colin",
             family = "Fay",
             role = c("cre", "aut"),
             email = "contact@colinfay.me",
             comment = c(ORCID = "0000-0001-7343-1846")),
      person(given = "ThinkR",
             role = "cph"),
      person(given = "Neo4J",
             role = "spn"))
Description: A Modern and Flexible 'Neo4J' Driver, allowing you to query
    data on a 'Neo4J' server and handle the results in R. It's modern in
    the sense it provides a driver
    that can be easily integrated in a data analysis workflow, especially by
    providing an API working smoothly with other data analysis and graph
    packages. It's flexible in the  way it returns the results, by
    trying to stay as close as
    possible to the way 'Neo4J' returns data. That way, you have the control
    over the way you will compute the results. At the same time, the result
    is not too complex, so that the "heavy lifting" of data wrangling is not
    left to the user.
License: MIT + file LICENSE
URL: https://github.com/neo4j-rstats/neo4r
BugReports: https://github.com/neo4j-rstats/neo4r/issues
Imports: attempt, data.table, glue, httr, jsonlite, magrittr, purrr (>=
        0.3.2), R6, rstudioapi, shiny, tibble, tidyr, utils
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-05-11 08:55:35 UTC; colinfay
Author: Colin Fay [cre, aut] (ORCID: <https://orcid.org/0000-0001-7343-1846>),
  ThinkR [cph],
  Neo4J [spn]
Maintainer: Colin Fay <contact@colinfay.me>
Repository: CRAN
Date/Publication: 2026-05-12 09:40:02 UTC
Built: R 4.6.0; ; 2026-05-12 10:21:20 UTC; unix
